package node

import (
	"blazing/logic/service/fight/info"
	"blazing/logic/service/fight/input"
)

// 命中前 攻击伤害结算
func (e *EffectNode) BeforHit(opp *input.Input, skill *info.SkillEntity) {

}

// 命中前 攻击伤害结算
func (e *EffectNode) AfterHit(opp *input.Input, skill *info.SkillEntity) {

}

// 命中时
func (e *EffectNode) OnHit(opp *input.Input, skill *info.SkillEntity) {

}

// miss触发
func (e *EffectNode) OnMiss(opp *input.Input, skill *info.SkillEntity) {

}

// 加算区
func (e *EffectNode) AddZone(opp *input.Input, skill *input.EffectID) {

}
//乘算区  
func (e *EffectNode) MulZone(opp *input.Input, skill *input.EffectID) {

}

// 受击触发
func (this *EffectNode) AfterAttacked(opp *input.Input, skill *info.SkillEntity) {
}
